@@ -4,12 +4,12 @@ use warnings;
 
 use Getopt::Std;
 my %opts;
-getopts('d:i:I:', \%opts);
+getopts('d:i:I:v', \%opts);
 
-die "Usage: chaos-query.pl -i dstIp [ -I srcIp ] [ -d device ]\n"
+die "Usage: chaos-query.pl -i dstIp [ -I srcIp ] [ -d device ] [ -v ]\n"
    unless $opts{i};
 
-$Net::Pkt::Debug++;
+$Net::Pkt::Debug = 3 if $opts{v};
 
 $Net::Pkt::Dev = $opts{d};
 $Net::Pkt::Ip  = $opts{I};
@@ -20,7 +20,7 @@ Net::Pkt::DescL3->new(ipDst => $opts{i});
 use Net::Pkt::Frame;
 use Net::Pkt::LayerIPv4 qw(/NETPKT_*/);
 my $l3 = Net::Pkt::LayerIPv4->new(
-   protocol => NETPKT_IPv4_TRANSPORT_UDP,
+   protocol => NETPKT_IPv4_PROTOCOL_UDP,
    src      => $Net::Pkt::Ip,
    dst      => $opts{i},
 );
@@ -38,22 +38,21 @@ use Net::Pkt::Dump;
 my $dump = Net::Pkt::Dump->new(
    filter             => $frame->getFilter,
    unlinkAfterAnalyze => 1,
+   callStart          => 1,
 );
 
-$dump->start;
-
 print "Request:\n";
 $frame->ipPrint;
 $frame->udpPrint;
 $frame->l7Print;
 $frame->send;
 
-$dump->stop;
-
-$dump->analyze;
-if (my $reply = $frame->recv) {
-   print "\nReply:\n";
-   $reply->ipPrint;
-   $reply->udpPrint;
-   $reply->l7Print;
+until ($Net::Pkt::Timeout) {
+   if ($dump->next && $frame->recv) {
+      print "\nReply:\n";
+      $frame->reply->ipPrint;
+      $frame->reply->udpPrint;
+      $frame->reply->l7Print;
+      last;
+   }
 }
